==> bplan-base-globals-1.1.0-0b4347.zip: lang/ru/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'ru',
    'language' => 'Русский',
    'locale' => 'ru_RU',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value руб.',
    'currency.format.negative' => '-:value руб.',
    'currency.iso4217.alpha'   => 'RUB',
    'currency.iso4217.numeric' => 643,
    'currency.name'            => 'Рубль',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Копейка',
    'currency.subunit.symbol'  => 'коп.',
    'currency.symbol'          => '₽',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y, H:i',
    'datetime.format+'  => 'd.m.Y, H:i:s',
    'datetime.format-+' => 'd.m.Y, H:i',
    'datetime.format++' => 'd.m.Y, H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => '.',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Активировать',
    'action.add'           => 'Добавить',
    'action.cancel'        => 'Отменить',
    'action.cancel-upload' => 'Отменить загрузку',
    'action.change'        => 'Изменить',
    'action.close'         => 'Закрыть',
    'action.confirm'       => 'Подтвердить',
    'action.deactivate'    => 'Деактивировать',
    'action.delete'        => 'Удалить',
    'action.edit'          => 'Редактировать',
    'action.import'        => 'Импортировать',
    'action.print'         => 'Печатать',
    'action.save'          => 'Сохранить',
    'action.search'        => 'Поиск',
    'action.sync'          => 'Синхронизировать',
    'action.upload'        => 'Загрузить файл',
    'action.verify'        => 'Проверить',
    'action.view'          => 'Просмотреть',

    'languages' => [
        'bg' => 'Болгарский',
        'de' => 'Немецкий',
        'en' => 'Английский',
        'es' => 'Испанский',
        'fr' => 'Французский',
        'hu' => 'Венгерский',
        'it' => 'Итальянский',
        'lt' => 'Литовский',
        'pl' => 'Польский',
        'ro' => 'Румынский',
        'ru' => 'Русский',
        'tr' => 'Турецкий',
        'uk' => 'Украинский',
    ],

    'option.yes' => 'Да',
    'option.no'  => 'Нет',

    'required-hint'   => 'Отмеченные поля (<span class="required-marker">:marker</span>) обязательны для заполнения',
    'required-marker' => '*',

    'select-option.please-select' => ' -- Пожалуйста, выберите -- ',

    'status.active'   => 'Активен',
    'status.expired'  => 'Истекший',
    'status.inactive' => 'Неактивен',
    'status.invalid'  => 'Недействителен',
    'status.loading'  => 'Загружается...',
    'status.not-set'  => 'Не установлен',
    'status.valid'    => 'Действителен',

];

==> bplan-base-globals-1.2.0-009337.zip: lang/ru/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'ru',
    'language' => 'Русский',
    'locale' => 'ru_RU',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value руб.',
    'currency.format.negative' => '-:value руб.',
    'currency.iso4217.alpha'   => 'RUB',
    'currency.iso4217.numeric' => 643,
    'currency.name'            => 'Рубль',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Копейка',
    'currency.subunit.symbol'  => 'коп.',
    'currency.symbol'          => '₽',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y, H:i',
    'datetime.format+'  => 'd.m.Y, H:i:s',
    'datetime.format-+' => 'd.m.Y, H:i',
    'datetime.format++' => 'd.m.Y, H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => '.',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Активировать',
    'action.add'           => 'Добавить',
    'action.cancel'        => 'Отменить',
    'action.cancel-upload' => 'Отменить загрузку',
    'action.change'        => 'Изменить',
    'action.close'         => 'Закрыть',
    'action.confirm'       => 'Подтвердить',
    'action.deactivate'    => 'Деактивировать',
    'action.delete'        => 'Удалить',
    'action.edit'          => 'Редактировать',
    'action.import'        => 'Импортировать',
    'action.print'         => 'Печатать',
    'action.save'          => 'Сохранить',
    'action.search'        => 'Поиск',
    'action.sync'          => 'Синхронизировать',
    'action.upload'        => 'Загрузить файл',
    'action.verify'        => 'Проверить',
    'action.view'          => 'Просмотреть',

    'languages' => [
        'bg' => 'Болгарский',
        'de' => 'Немецкий',
        'en' => 'Английский',
        'es' => 'Испанский',
        'fr' => 'Французский',
        'hu' => 'Венгерский',
        'it' => 'Итальянский',
        'lt' => 'Литовский',
        'pl' => 'Польский',
        'ro' => 'Румынский',
        'ru' => 'Русский',
        'tr' => 'Турецкий',
        'uk' => 'Украинский',
    ],

    'option.yes' => 'Да',
    'option.no'  => 'Нет',

    'required-hint'   => 'Отмеченные поля (<span class="required-marker">:marker</span>) обязательны для заполнения',
    'required-marker' => '*',

    'select-option.no-options-available' => 'Опции отсутствуют',
    'select-option.please-select'        => ' -- Пожалуйста, выберите -- ',

    'status.active'   => 'Активен',
    'status.expired'  => 'Истекший',
    'status.inactive' => 'Неактивен',
    'status.invalid'  => 'Недействителен',
    'status.loading'  => 'Загружается...',
    'status.not-set'  => 'Не установлен',
    'status.valid'    => 'Действителен',

];
